@@ -1,10 +1,9 @@
 use strict;
 use warnings;
 
-package
-    Games::Sudoku::Trainer::Priorities;
+package Games::Sudoku::Trainer::Priorities;
 
-use version; our $VERSION = qv('0.0.2');    # PBP
+use version; our $VERSION = qv('0.02');    # PBP
 
 # globals
 my @strategies;    # strategies arranged by current priorities
